local lcDirectory, ;
	lcDataDir, ;
	lcSampleDir, ;
	laFiles[1], ;
	lnFiles, ;
	lnI, ;
	lcFile

* Set up the environment.

set talk off
set deleted on
set safety off
set notify off
close databases all

* Set some file location variables.

lcDirectory = left(sys(16), rat('\', sys(16)))
lcDataDir   = lcDirectory + 'data\'
lcSampleDir = iif(type('_samples') = 'U', home() + 'samples\', _samples)

* Ensure we have a DATA subdirectory.

if not directory(lcDataDir)
	md (lcDataDir)
endif not directory(lcDataDir)

* Copy the VFP TESTDATA database and tables to the DATA subdirectory.

lnFiles = adir(laFiles, lcSampleDir + 'data\*.*')
for lnI = 1 to lnFiles
	lcFile = laFiles[lnI, 1]
	if inlist(right(lcFile, 3), 'DBF', 'FPT', 'CDX', 'DBC', 'DCX', 'DCT')
		copy file (lcSampleDir + 'data\' + lcFile) to (lcDataDir + lcFile)
	endif inlist(right(lcFile, 3), ...
next lnI

* Remove files we don't need.

erase (lcDataDir + 'country.*')
erase (lcDataDir + 'queries.*')

* Alter the stored procedures and set up the triggers we need.

open database (lcDataDir + 'testdata.dbc') exclusive
append procedures from (lcDirectory + 'ricode.prg') overwrite
compile database (dbc())
create trigger on customer for delete as __ri_delete_customer()
create trigger on orders   for delete as __ri_delete_orders()

* Create a view we'll use

create sql view lvorders as ;
	select customer.cust_id, ;
			orders.order_id, ;
			orditems.line_no ;
		from orders ;
			left outer join orditems ;
				on orders.order_id = orditems.order_id ;
			left outer join customer ;
				on orders.cust_id = customer.cust_id ;
		order by 1, 2, 3
close tables all

* Remove ORDITEMS records we don't want.

use ORDITEMS exclusive
delete for ORDER_ID = ' 10062'
pack
close databases all

* Change the RI rules for certain relations.

use (lcDataDir + 'testdata.dbc')
scan for ObjectType = 'Relation'
	do case
		case ObjectName = 'cust_id'
			replace RIInfo with 'ICI'
		case ObjectName = 'order_id'
			replace RIInfo with 'IRI'
		otherwise
			replace RIInfo with ''
	endcase
endscan for ObjectType = 'Relation'
use
